From 2cdfb2ff48e9933d9d957fd706a449bf5a6f322f Mon Sep 17 00:00:00 2001
From: Soren Stoutner <soren@stoutner.com>
Date: Fri, 21 Apr 2023 15:14:04 -0700
Subject: [PATCH] Add GNOME edit current domain settings icon. 
 https://redmine.stoutner.com/issues/999

---
 changelog                                   | 4 ++--
 src/com.stoutner.privacybrowser.appdata.xml | 4 ++--
 src/main.cpp                                | 2 +-
 src/widgets/TabWidget.cpp                   | 3 ++-
 src/windows/BrowserWindow.cpp               | 3 ++-
 5 files changed, 9 insertions(+), 7 deletions(-)

diff --git a/changelog b/changelog
index d0a3d56..3ac729d 100644
--- a/changelog
+++ b/changelog
@@ -1,6 +1,6 @@
 # Version 0.2 (17 April 2023)
- * Fix a crash on Gnome when downloading a file with local storage disabled.
- * Fix problems with missing icons on Gnome.
+ * Fix a crash on GNOME when downloading a file with local storage disabled.
+ * Fix problems with missing icons on GNOME.
  * Display an animated favorite icon while a webpage is loading.
  * Fix the Handbook on non-KDE systems.
  * Change the order of entries in the WebEngine context menu.
diff --git a/src/com.stoutner.privacybrowser.appdata.xml b/src/com.stoutner.privacybrowser.appdata.xml
index bb57891..d55d891 100644
--- a/src/com.stoutner.privacybrowser.appdata.xml
+++ b/src/com.stoutner.privacybrowser.appdata.xml
@@ -46,8 +46,8 @@
     <releases>
         <release version="0.2" date="2023-04-17">
             <description>
-                <p>Fix a crash on Gnome when downloading a file with local storage disabled.</p>
-                <p>Fix problems with missing icons on Gnome.</p>
+                <p>Fix a crash on GNOME when downloading a file with local storage disabled.</p>
+                <p>Fix problems with missing icons on GNOME.</p>
                 <p>Display an animated favorite icon while a webpage is loading.</p>
                 <p>Fix the Handbook on non-KDE systems.</p>
                 <p>Change the order of entries in the WebEngine context menu.</p>
diff --git a/src/main.cpp b/src/main.cpp
index 1047b1f..3dac570 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -45,7 +45,7 @@ int main(int argc, char *argv[])
     KCrash::initialize();
 
     // Instantiate about data, setting the component name, the display name, and the version.
-    KAboutData aboutData(QStringLiteral("privacybrowser"), i18nc("Program Name", "Privacy Browser"), QStringLiteral("0.1"));
+    KAboutData aboutData(QStringLiteral("privacybrowser"), i18nc("Program Name", "Privacy Browser"), QStringLiteral("0.2"));
 
     // Add the author name, job description, email address, and website.
     aboutData.addAuthor(i18nc("Developer Information", "Soren Stoutner"),i18nc("Developer Information", "Principal developer"), QStringLiteral("soren@stoutner.com"),
diff --git a/src/windows/BrowserWindow.cpp b/src/windows/BrowserWindow.cpp
index 6347ec4..c2497aa 100644
--- a/src/windows/BrowserWindow.cpp
+++ b/src/windows/BrowserWindow.cpp
@@ -339,7 +339,8 @@ BrowserWindow::BrowserWindow(bool firstWindow) : KXmlGuiWindow()
     findTextLineEditPointer->setClearButtonEnabled(true);
 
     // Add an edit or add domain settings action to the URL line edit.
-    QAction *addOrEditDomainSettingsActionPointer = urlLineEditPointer->addAction(QIcon::fromTheme("settings-configure"), QLineEdit::TrailingPosition);
+    QAction *addOrEditDomainSettingsActionPointer = urlLineEditPointer->addAction(QIcon::fromTheme("settings-configure", QIcon::fromTheme(QLatin1String("preferences-desktop"))),
+                                                                                  QLineEdit::TrailingPosition);
 
     // Add or edit the current domain settings.
     connect(addOrEditDomainSettingsActionPointer, SIGNAL(triggered()), this, SLOT(addOrEditDomainSettings()));
diff --git a/src/widgets/TabWidget.cpp b/src/widgets/TabWidget.cpp
index cbb84b3..28a6cf2 100644
--- a/src/widgets/TabWidget.cpp
+++ b/src/widgets/TabWidget.cpp
@@ -1103,7 +1103,8 @@ void TabWidget::useNativeKdeDownloader(QUrl &downloadUrl, QString &suggestedFile
         // Create a file copy job.  `-1` creates the file with default permissions.
         KIO::FileCopyJob *fileCopyJobPointer = KIO::file_copy(downloadUrl, saveLocation, -1, KIO::Overwrite);
 
-        // Set the download job to display any error messages.
+        // Set the download job to display any warning and error messages.
+        fileCopyJobPointer->uiDelegate()->setAutoWarningHandlingEnabled(true);
         fileCopyJobPointer->uiDelegate()->setAutoErrorHandlingEnabled(true);
 
         // Start the download.
-- 
2.47.2